from pymacaron.log import pymlogger


log = pymlogger(__name__)


#
# This module contains all PyMacaron models generated from the OpenAPI schema
# They are dynamically injected into pymacaron.models's global namespace when
# the OpenAPI specification is loaded.
#
# Models can therefore be imported by name, as follows:
#
# from pymacaron.models import ModelName
#
